// ***********************************************************************
// **     ___---__-->   The Peroxide Programming Tips   <--__---___     **
// **                                                                   **
// **     demo program 1 : Does nothing but create a window and         **
// **                      setup a simple event handler                 **
// ***********************************************************************

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <windowsx.h>




// ********* Global Variables ***************

HWND main_window = NULL;



// ********* Functions **************


LRESULT CALLBACK MyEventHandler (HWND hwnd, UINT msg, WPARAM wparam, LPARAM lparam)
 {
 	
    HDC deviceContext;
    PAINTSTRUCT paintstruct;
    
    switch(msg)
      {
      	case WM_CREATE:
      	  {
      	   // Init app here - nothing to init in this simple case
      	   
      	   return(0); // tell Windows we handled the event
      	} break;
      	
      	case WM_PAINT:
      	  {
      	   // repaint window. In this case window has no content so we just
      	   // begin and end the repainting. We HAS to do this, or Windows will
      	   // think we didn't get the message and will resend it again and again!
      	   deviceContext = BeginPaint(hwnd, &paintstruct);
      	   EndPaint(hwnd, &paintstruct);
      	   
      	   return(0); // Tell windows we handled the event 
        } break;
        
        case WM_DESTROY:
          {
           // post a WM_QUIT message to the message queue to let the main loop terminate
           PostQuitMessage(0); 
           
           return(0); // tell Windows we handled the event
        } break;
        
        default : break;
        
       } //switch

   return(DefWindowProc(hwnd, msg, wparam, lparam)); // let Windows have a look at any messages
                                                  // we didn't handle
 }
 
 
 
 
 // *********** WinMain() **************
 
 int WINAPI WinMain(HINSTANCE hinstance, HINSTANCE previnst, LPSTR lpcmdline, int ncmdshow)
  {
    
   WNDCLASS windowsClass;
   
   // now we fill out the fields in the windows class as described in the tutorial.
   windowsClass.style = CS_DBLCLKS | CS_OWNDC | CS_HREDRAW | CS_VREDRAW;
   windowsClass.lpfnWndProc = MyEventHandler;
   windowsClass.cbClsExtra = 0;
   windowsClass.cbWndExtra = 0;
   windowsClass.hInstance = hinstance; // from WinMain()
   windowsClass.hIcon = LoadIcon(NULL, IDI_APPLICATION);
   windowsClass.hCursor = LoadCursor(NULL, IDC_ARROW);
   windowsClass.hbrBackground = GetStockObject(WHITE_BRUSH);
   windowsClass.lpszMenuName = NULL;
   windowsClass.lpszClassName = "MyVeryFirstWindowsClass";
   
   // register the class with Windows :
   if (!RegisterClass(&windowsClass))
     {
     	// an error occured..
     	MessageBox(NULL, "Error registering the Window Class.\nPlease try again!","Error!",MB_OK);
     	return(0);
      }
                         	
   // create the window
   main_window = CreateWindow("MyVeryFirstWindowsClass",
                              "Pxdtut 9 - demo program 1", //title
                              WS_OVERLAPPEDWINDOW | WS_VISIBLE,  //the style
                              50,50,300,200,               //pos and size
                              NULL,NULL,
                              hinstance,                   //from WinMain()
                              NULL);
                             
   //test if window was created succesfully
   if (main_window == NULL)
     {
     	// error occured..
     	MessageBox(NULL, "Error creating the window.\nPlease try again!", "Error!", MB_OK);
     	return(0);
       }
       
   MSG msg;     
   while(TRUE)
    {
      if (PeekMessage(&msg, NULL, 0,0, PM_REMOVE))
       {
       	 if (msg.message == WM_QUIT) break; // break out of loop if quit message posted.
       	 
       	 TranslateMessage(&msg);
       	 DispatchMessage(&msg); // let Event handler look at the message
       	 } 	
   	
  	
     // Add none-message related code here - like the inner loop of a game
     
  }
  
  return(msg.wParam); // return to Windows
 } // end WinMain()
       
	
 
 
